@@ -956,8 +956,11 @@ void WorkflowInstance::run_tasks(DOMElement job,DOMElement context_node)
 	unique_ptr<DOMXPathResult> res(xmldoc->evaluate("count(tasks/task[(@status='TERMINATED' and @retval = 0) or (@status='SKIPPED')])",job,DOMXPathResult::FIRST_RESULT_TYPE));
 	int tasks_successful = res->getIntegerValue();
 	
+	unique_ptr<DOMXPathResult> res2(xmldoc->evaluate("count(tasks/task)",job,DOMXPathResult::FIRST_RESULT_TYPE));
+	int tasks_total = res2->getIntegerValue();
+	
 	// If all task of job is skipped goto child job :
-	if (tasks_successful == tasks_index-1){
+	if (tasks_successful == tasks_total){
 		run_subjobs(job);
 	}
 }
@@ -1003,20 +1006,18 @@ bool WorkflowInstance::run_task(DOMElement task,DOMElement context_node)
 
 void WorkflowInstance::register_job_functions(DOMElement node)
 {
-	static DOMElement job, parent_job;
 	if(node.getNodeName()=="task")
-		job = node.getParentNode().getParentNode();
+		context_job = node.getParentNode().getParentNode();
 	else
-		job = node;
+		context_job = node;
 	
+	xmldoc->getXPath()->RegisterFunction("evqGetCurrentJob",{WorkflowXPathFunctions::evqGetCurrentJob,&context_job});
 	
-	xmldoc->getXPath()->RegisterFunction("evqGetCurrentJob",{WorkflowXPathFunctions::evqGetCurrentJob,&job});
-	
-	parent_job = job.getParentNode().getParentNode();
-	xmldoc->getXPath()->RegisterFunction("evqGetParentJob",{WorkflowXPathFunctions::evqGetParentJob,&parent_job});
-	xmldoc->getXPath()->RegisterFunction("evqGetOutput",{WorkflowXPathFunctions::evqGetOutput,&parent_job});
-	xmldoc->getXPath()->RegisterFunction("evqGetInput",{WorkflowXPathFunctions::evqGetInput,&parent_job});
-	xmldoc->getXPath()->RegisterFunction("evqGetContext",{WorkflowXPathFunctions::evqGetContext,&parent_job});
+	context_parent_job = context_job.getParentNode().getParentNode();
+	xmldoc->getXPath()->RegisterFunction("evqGetParentJob",{WorkflowXPathFunctions::evqGetParentJob,&context_parent_job});
+	xmldoc->getXPath()->RegisterFunction("evqGetOutput",{WorkflowXPathFunctions::evqGetOutput,&context_parent_job});
+	xmldoc->getXPath()->RegisterFunction("evqGetInput",{WorkflowXPathFunctions::evqGetInput,&context_parent_job});
+	xmldoc->getXPath()->RegisterFunction("evqGetContext",{WorkflowXPathFunctions::evqGetContext,&context_parent_job});
 }
 
 void WorkflowInstance::run_subjobs(DOMElement job)
